// Steve Quinn 01/01/17
//
// Copyright 2017 Steve Quinn
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
//
// Compiled using Arduino 1.6.9 and tested with Arduino Uno R3
//
// Used to compare Tiny85_I2C_Slave_PWM_1.ino with Tiny85_I2C_Slave_PWM_2.ino 
//
// Sends fixed values 255,0,64,0,128,0,192,0,255,128,255,128,255,0 to I2C slave PWM device every 3 seconds. Then repeats.
//
//

#include <Wire.h>
#include <LiquidCrystal_I2C_PCF8574.h>

typedef struct {
  uint8_t pwmValue;
  int delayValue;
} tPWMValueStruct;

const tPWMValueStruct pwmValueTable[] = {
  {255, 3000}, 
  {  0, 3000}, 
  { 64, 3000}, 
  {  0, 3000}, 
  {128, 3000}, 
  {  0, 3000}, 
  {192, 3000}, 
  {  0, 3000}, 
  {255, 3000}, 
  {  0, 3000}
};

#define SLAVE_ADDR1  0x08         // Easing function
#define SLAVE_ADDR2  0x09         // Linear response
#define LCD_ADDR1    0x23         // LCD1
#define LCD_ADDR2    0x27         // LCD2

LiquidCrystal_I2C_PCF8574 lcd1(LCD_ADDR1,20,4);  // set the LCD address to 0x27 for a 20 chars and 4 line display
LiquidCrystal_I2C_PCF8574 lcd2(LCD_ADDR2,20,4);  // set the LCD address to 0x27 for a 20 chars and 4 line display


#define __FILENAME__ (strrchr(__FILE__, '\\') ? strrchr(__FILE__, '\\') + 1 : __FILE__)

void setup()
{
  Wire.begin();
  Serial.begin(115200);
  Serial.println(__FILENAME__);
  Serial.println("Serial Port Ready");
  lcd1.init();                      // initialize lcd1 
  lcd1.backlight();
  lcd1.setCursor(0,0);
  lcd1.writeStr("                    "); // print message
  lcd1.setCursor(0,1);
  lcd1.writeStr("  Linear Function   "); // print message
  lcd1.setCursor(0,2);
  lcd1.writeStr("                    "); // print message
  lcd1.setCursor(0,3);
  lcd1.writeStr("                    "); // print message

  lcd2.init();                      // initialize lcd1 
  lcd2.backlight();
  lcd2.setCursor(0,0);
  lcd2.writeStr("                    "); // print message
  lcd2.setCursor(0,1);
  lcd2.writeStr("  Eased Function    "); // print message
  lcd2.setCursor(0,2);
  lcd2.writeStr("                    "); // print message
  lcd2.setCursor(0,3);
  lcd2.writeStr("                    "); // print message
  delay(3000);
  
}


void loop()
{
  byte error;
  byte x = 0;
  char tmpString[100];
  int maxPWMValues =  sizeof(pwmValueTable)/sizeof(tPWMValueStruct);
  for (int index = 0; index < maxPWMValues; index++)
  {
    sprintf(tmpString,"%d",pwmValueTable[index].pwmValue);
    lcd1.setCursor(0,2);
    lcd1.writeStr("  PWM Value :       "); // clear line
    lcd1.setCursor(14,2);
    lcd1.writeStr(tmpString); // print message

    lcd2.setCursor(0,2);
    lcd2.writeStr("  PWM Value :       "); // clear line
    lcd2.setCursor(14,2);
    lcd2.writeStr(tmpString); // print message

    Wire.beginTransmission(SLAVE_ADDR1); 
    Wire.write((byte)pwmValueTable[index].pwmValue);
    error = Wire.endTransmission();
    
    Wire.beginTransmission(SLAVE_ADDR2); 
    Wire.write((byte)pwmValueTable[index].pwmValue);
    error = Wire.endTransmission();
    
    delay(pwmValueTable[index].delayValue);
  }
}

